# This file was auto-generated by Fern from our API Definition.

import typing

TimeSeriesComponentUpdateRequestChartType = typing.Union[
    typing.Literal["line", "area", "bar", "scatter", "candlestick"], typing.Any
]
